@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
-import re, os
+import os
+from . import regex as re
 from .common import build_where_msg, tohuman, \
                     enhance_exceptions
 
@@ -383,7 +384,7 @@ class ExampleHarvest(object):
         charno = 0
         items = []
 
-        for match in matcher.get_matches(string):
+        for match in matcher.get_matches(string, filepath):
             str_matched = string[match.start():match.end()]
             if str_matched.endswith('\n'):
                 str_matched = str_matched[:-1]
@@ -412,7 +413,7 @@ class ExampleFinder(object):
     def example_regex(self):
         raise NotImplementedError()  # pragma: no cover
 
-    def get_matches(self, string):
+    def get_matches(self, string, filepath='<string>'):
         return self.example_regex().finditer(string)
 
     def get_language_of(self, options, match, where):
@@ -476,14 +477,14 @@ class ExampleFinder(object):
         'check_and_remove_indent' and other processing functions.
 
             >>> from byexample.finder import ExampleFinder
-            >>> import re
+            >>> import byexample.regex as re
 
             >>> mfinder = ExampleFinder(0, 'utf8'); mfinder.target = 'python-prompt'
             >>> check_and_remove_indent = mfinder.check_and_remove_indent
             >>> check_keep_matching     = mfinder.check_keep_matching
 
             >>> code = '  >>> 1 + 2'
-            >>> match = re.match(r'[ ]*>>> [^\n]*', code)
+            >>> match = re.compile(r'[ ]*>>> [^\n]*').match(code)
 
             >>> code_i = check_and_remove_indent(code, '  ', (1, 2, 'foo.rst', None))
             >>> code_i != code
@@ -563,7 +564,7 @@ class ZoneDelimiter(object):
     def zone_regex(self):
         raise NotImplementedError()  # pragma: no cover
 
-    def get_matches(self, string):
+    def get_matches(self, string, filepath='<string>'):
         return self.zone_regex().finditer(string)
 
     def get_zone(self, match, where):
