@@ -33,7 +33,7 @@ Example:
 """
 
 from __future__ import unicode_literals
-import re
+import byexample.regex as re
 from byexample.common import constant, abspath
 from byexample.parser import ExampleParser
 from byexample.finder import ExampleFinder
@@ -113,7 +113,7 @@ class JavascriptInterpreter(ExampleRunner, PexpectMixin):
         return "%e %p %a", {
             'e': '/usr/bin/env',
             'p': 'nodejs',
-            'a': [abspath(__file__, 'byexample-repl.js')]
+            'a': [abspath(__file__, 'gadgets', 'byexample-repl.js')]
         }
 
     def initialize(self, options):
