@@ -23,7 +23,8 @@ Example:
 """
 
 from __future__ import unicode_literals
-import re, pexpect, sys, time
+import pexpect, sys, time
+import byexample.regex as re
 from byexample.common import constant
 from byexample.log import clog
 from byexample.parser import ExampleParser, ExtendOptionParserMixin
