@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
-import re, shlex, argparse, bisect, collections
+import shlex, argparse, bisect, collections
+from . import regex as re
 from .common import tohuman, constant
 from .options import OptionParser, UnrecognizedOption, ExtendOptionParserMixin
 from .expected import _LinearExpected, _RegexExpected
@@ -218,7 +219,7 @@ class ExampleParser(ExtendOptionParserMixin):
 
             >>> from byexample.parser import ExampleParser
             >>> from functools import partial
-            >>> import re
+            >>> import byexample.regex as re
 
             >>> parser = ExampleParser(0, 'utf8', None); parser.language = 'python'
             >>> _as_regexs = partial(parser.expected_as_regexs, tags_enabled=True, input_enabled=True, normalize_whitespace=False, input_prefix_len_range=(6,12))
